HttpResult

Type Alias HttpResult 

pub type HttpResult<T> = Result<T, HttpError>;
The result of an HTTP request.

Often times, the type argument T is either a String, or a type that can be deserialized with serde_json.

Aliased Type

pub enum HttpResult<T> {
    Ok(T),
    Err(HttpError),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(HttpError)

Contains the error value